var WelcomScreen = {
	canPlay: function() {
		var useragent = navigator.userAgent.toLowerCase();
		var isSafari4 = false;
		var isSafari = useragent.match(/version\/([\d\.]*) safari/);
		if (isSafari) {
			var isSafari4 = (parseInt(isSafari[1])>3);
		}

		if (!isSafari4) {
			document.body.innerHTML = '<p class="download">Download the <a href="/safari/">Safari 4 Public Beta</a> to view this page.</p>'
			return false;
		}

		return true;
	},
	localizeWelcomeMessage: function() {
	    var localizedWelcomeMessages = {
	        "da-dk": "Velkommen til Safari 4",
	        "de-de": "Willkommen bei Safari 4",
	        "es-es": "Bienvenido a Safari 4",
	        "fi-fi": "Tervetuloa Safari 4",
	        "fr-fr": "Bienvenue dans Safari 4",
	        "it-it": "Benvenuti in Safari 4",
	        "ja-jp": "Safari 4へようこそ",
	        "ko-kr": "Safari  4사용을 환영합니다",
	        "nb-no": "Velkommen til Safari 4",
	        "nl-nl": "Welkom bij Safari 4",
	        "pl-pl": "Witamy w Safari 4",
	        "pt-br": "Bem-vindo ao Safari 4",
	        "pt-pt": "Bem-vindo ao Safari 4",
	        "ru-ru": "Добро пожаловать в Safari 4",
	        "sv-se": "Välkommen till Safari 4",
	        "zh-cn": "欢迎使用 Safari 4",
	        "zh-tw": "歡迎使用 Safari 4",
	        // "Hong Kong (Traditional Chinese)": "歡迎來到 Safari 4",
	    };

	    var localizedMessage = localizedWelcomeMessages[navigator.language];
	    if (!localizedMessage)
	        return;

	    document.getElementsByTagName("h1")[0].innerHTML = localizedMessage;
	},
	
	initialize: function() {
		if (this.canPlay()) {
			this.localizeWelcomeMessage();
			this.music = document.getElementById('music');
			this.video = document.getElementById('compass');

			var self = this;
			function animationStart(event) {
				if (event.animationName === 'safari-video')
					self.video.play();
			}

			function animationEnded(event) {
				if (event.animationName === 'safari-video')
					self.redirect();
			}

			function musicEnded(event) {
				self.redirect();
			}

			if ("play" in this.music)
				this.music.addEventListener('ended', musicEnded, false);
			else
				window.addEventListener('webkitAnimationEnd', animationEnded, false);

			window.addEventListener('webkitAnimationStart', animationStart, false);

			this.preloadMedia();
		}
	},

	preloadMedia: function() {
		var mediaFound = 0;
		var mediaLoaded = 0;

		var self = this;
		function mediaDidLoad() {
			++mediaLoaded;
			if (mediaLoaded >= mediaFound)
				self.start();
		}

		var audioElements = document.getElementsByTagName('audio');
		for (var i = 0; i < audioElements.length; ++i) {
			var audio = audioElements[i];
			if (!("load" in audio) || !audio.src)
				continue;
			++mediaFound;
			audio.addEventListener('load', mediaDidLoad, false);
			audio.load();
		}

		var videoElements = document.getElementsByTagName('video');
		for (var i = 0; i < videoElements.length; ++i) {
			var video = videoElements[i];
			if (!("load" in video) || !video.src)
				continue;
			++mediaFound;
			video.addEventListener('load', mediaDidLoad, false);
			video.load();
		}

		var rules = document.styleSheets[0].rules;
		for (var i = 0; i < rules.length; ++i) {
			var rule = rules[i];
			var urls = rule.cssText.match(/url\([^\)]*\)/g);
			if (!urls)
				continue;

			mediaFound += urls.length;

			for (var j = 0; j < urls.length; ++j) {
				var url = urls[j].substring(4, (urls[j].length - 1)); // Remove the "url(" prefix and ")" suffix.
				var image = new Image();
				image.addEventListener('load', mediaDidLoad, false);
				image.src = url;
			}
		}
	},

	start: function() {
		if ("play" in this.music)
			this.music.play();
		document.body.className = 'go';
	},

	redirect: function() {
		document.location = 'topsites://';
	}
};

try {
	window.addEventListener('load', function() {
		WelcomScreen.initialize();
	}, false);

	window.addEventListener('unload', function() {
		document.body.className = '';
	}, false);
} catch (e) {
	window.onload = WelcomScreen.canPlay;
}
